Gandi Pyramid Prometheus
========================

.. image:: https://travis-ci.org/Gandi/gandi-pyramid-prometheus.svg?branch=master
    :target: https://travis-ci.org/Gandi/gandi-pyramid-prometheus

A prometheus client library for general metrics from pyramid.

